# pulp_rpm_client

PulpRpmClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 3.25.3
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_rpm_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_rpm_client-3.25.3.gem
```

(for development, run `gem install --dev ./pulp_rpm_client-3.25.3.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_rpm_client', '~> 3.25.3'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_rpm_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_rpm_client'

# Setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpRpmClient::AcsRpmApi.new
rpm_rpm_alternate_content_source_href = 'rpm_rpm_alternate_content_source_href_example' # String | 
nested_role = PulpRpmClient::NestedRole.new # NestedRole | 

begin
  #Add a role
  result = api_instance.add_role(rpm_rpm_alternate_content_source_href, nested_role)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling AcsRpmApi->add_role: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpRpmClient::AcsRpmApi* | [**add_role**](docs/AcsRpmApi.md#add_role) | **POST** {rpm_rpm_alternate_content_source_href}add_role/ | Add a role
*PulpRpmClient::AcsRpmApi* | [**create**](docs/AcsRpmApi.md#create) | **POST** /pulp/api/v3/acs/rpm/rpm/ | Create a rpm alternate content source
*PulpRpmClient::AcsRpmApi* | [**delete**](docs/AcsRpmApi.md#delete) | **DELETE** {rpm_rpm_alternate_content_source_href} | Delete a rpm alternate content source
*PulpRpmClient::AcsRpmApi* | [**list**](docs/AcsRpmApi.md#list) | **GET** /pulp/api/v3/acs/rpm/rpm/ | List rpm alternate content sources
*PulpRpmClient::AcsRpmApi* | [**list_roles**](docs/AcsRpmApi.md#list_roles) | **GET** {rpm_rpm_alternate_content_source_href}list_roles/ | List roles
*PulpRpmClient::AcsRpmApi* | [**my_permissions**](docs/AcsRpmApi.md#my_permissions) | **GET** {rpm_rpm_alternate_content_source_href}my_permissions/ | List user permissions
*PulpRpmClient::AcsRpmApi* | [**partial_update**](docs/AcsRpmApi.md#partial_update) | **PATCH** {rpm_rpm_alternate_content_source_href} | Update a rpm alternate content source
*PulpRpmClient::AcsRpmApi* | [**read**](docs/AcsRpmApi.md#read) | **GET** {rpm_rpm_alternate_content_source_href} | Inspect a rpm alternate content source
*PulpRpmClient::AcsRpmApi* | [**refresh**](docs/AcsRpmApi.md#refresh) | **POST** {rpm_rpm_alternate_content_source_href}refresh/ | 
*PulpRpmClient::AcsRpmApi* | [**remove_role**](docs/AcsRpmApi.md#remove_role) | **POST** {rpm_rpm_alternate_content_source_href}remove_role/ | Remove a role
*PulpRpmClient::AcsRpmApi* | [**update**](docs/AcsRpmApi.md#update) | **PUT** {rpm_rpm_alternate_content_source_href} | Update a rpm alternate content source
*PulpRpmClient::ContentAdvisoriesApi* | [**create**](docs/ContentAdvisoriesApi.md#create) | **POST** /pulp/api/v3/content/rpm/advisories/ | Create an update record
*PulpRpmClient::ContentAdvisoriesApi* | [**list**](docs/ContentAdvisoriesApi.md#list) | **GET** /pulp/api/v3/content/rpm/advisories/ | List update records
*PulpRpmClient::ContentAdvisoriesApi* | [**read**](docs/ContentAdvisoriesApi.md#read) | **GET** {rpm_update_record_href} | Inspect an update record
*PulpRpmClient::ContentDistributionTreesApi* | [**list**](docs/ContentDistributionTreesApi.md#list) | **GET** /pulp/api/v3/content/rpm/distribution_trees/ | List distribution trees
*PulpRpmClient::ContentDistributionTreesApi* | [**read**](docs/ContentDistributionTreesApi.md#read) | **GET** {rpm_distribution_tree_href} | Inspect a distribution tree
*PulpRpmClient::ContentModulemdDefaultsApi* | [**create**](docs/ContentModulemdDefaultsApi.md#create) | **POST** /pulp/api/v3/content/rpm/modulemd_defaults/ | Create a modulemd defaults
*PulpRpmClient::ContentModulemdDefaultsApi* | [**list**](docs/ContentModulemdDefaultsApi.md#list) | **GET** /pulp/api/v3/content/rpm/modulemd_defaults/ | List modulemd defaultss
*PulpRpmClient::ContentModulemdDefaultsApi* | [**read**](docs/ContentModulemdDefaultsApi.md#read) | **GET** {rpm_modulemd_defaults_href} | Inspect a modulemd defaults
*PulpRpmClient::ContentModulemdObsoletesApi* | [**create**](docs/ContentModulemdObsoletesApi.md#create) | **POST** /pulp/api/v3/content/rpm/modulemd_obsoletes/ | Create a modulemd obsolete
*PulpRpmClient::ContentModulemdObsoletesApi* | [**list**](docs/ContentModulemdObsoletesApi.md#list) | **GET** /pulp/api/v3/content/rpm/modulemd_obsoletes/ | List modulemd obsoletes
*PulpRpmClient::ContentModulemdObsoletesApi* | [**read**](docs/ContentModulemdObsoletesApi.md#read) | **GET** {rpm_modulemd_obsolete_href} | Inspect a modulemd obsolete
*PulpRpmClient::ContentModulemdsApi* | [**create**](docs/ContentModulemdsApi.md#create) | **POST** /pulp/api/v3/content/rpm/modulemds/ | Create a modulemd
*PulpRpmClient::ContentModulemdsApi* | [**list**](docs/ContentModulemdsApi.md#list) | **GET** /pulp/api/v3/content/rpm/modulemds/ | List modulemds
*PulpRpmClient::ContentModulemdsApi* | [**read**](docs/ContentModulemdsApi.md#read) | **GET** {rpm_modulemd_href} | Inspect a modulemd
*PulpRpmClient::ContentPackagecategoriesApi* | [**list**](docs/ContentPackagecategoriesApi.md#list) | **GET** /pulp/api/v3/content/rpm/packagecategories/ | List package categorys
*PulpRpmClient::ContentPackagecategoriesApi* | [**read**](docs/ContentPackagecategoriesApi.md#read) | **GET** {rpm_package_category_href} | Inspect a package category
*PulpRpmClient::ContentPackageenvironmentsApi* | [**list**](docs/ContentPackageenvironmentsApi.md#list) | **GET** /pulp/api/v3/content/rpm/packageenvironments/ | List package environments
*PulpRpmClient::ContentPackageenvironmentsApi* | [**read**](docs/ContentPackageenvironmentsApi.md#read) | **GET** {rpm_package_environment_href} | Inspect a package environment
*PulpRpmClient::ContentPackagegroupsApi* | [**list**](docs/ContentPackagegroupsApi.md#list) | **GET** /pulp/api/v3/content/rpm/packagegroups/ | List package groups
*PulpRpmClient::ContentPackagegroupsApi* | [**read**](docs/ContentPackagegroupsApi.md#read) | **GET** {rpm_package_group_href} | Inspect a package group
*PulpRpmClient::ContentPackagelangpacksApi* | [**list**](docs/ContentPackagelangpacksApi.md#list) | **GET** /pulp/api/v3/content/rpm/packagelangpacks/ | List package langpackss
*PulpRpmClient::ContentPackagelangpacksApi* | [**read**](docs/ContentPackagelangpacksApi.md#read) | **GET** {rpm_package_langpacks_href} | Inspect a package langpacks
*PulpRpmClient::ContentPackagesApi* | [**create**](docs/ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/rpm/packages/ | Create a package
*PulpRpmClient::ContentPackagesApi* | [**list**](docs/ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/rpm/packages/ | List packages
*PulpRpmClient::ContentPackagesApi* | [**read**](docs/ContentPackagesApi.md#read) | **GET** {rpm_package_href} | Inspect a package
*PulpRpmClient::ContentRepoMetadataFilesApi* | [**list**](docs/ContentRepoMetadataFilesApi.md#list) | **GET** /pulp/api/v3/content/rpm/repo_metadata_files/ | List repo metadata files
*PulpRpmClient::ContentRepoMetadataFilesApi* | [**read**](docs/ContentRepoMetadataFilesApi.md#read) | **GET** {rpm_repo_metadata_file_href} | Inspect a repo metadata file
*PulpRpmClient::DistributionsRpmApi* | [**add_role**](docs/DistributionsRpmApi.md#add_role) | **POST** {rpm_rpm_distribution_href}add_role/ | Add a role
*PulpRpmClient::DistributionsRpmApi* | [**create**](docs/DistributionsRpmApi.md#create) | **POST** /pulp/api/v3/distributions/rpm/rpm/ | Create a rpm distribution
*PulpRpmClient::DistributionsRpmApi* | [**delete**](docs/DistributionsRpmApi.md#delete) | **DELETE** {rpm_rpm_distribution_href} | Delete a rpm distribution
*PulpRpmClient::DistributionsRpmApi* | [**list**](docs/DistributionsRpmApi.md#list) | **GET** /pulp/api/v3/distributions/rpm/rpm/ | List rpm distributions
*PulpRpmClient::DistributionsRpmApi* | [**list_roles**](docs/DistributionsRpmApi.md#list_roles) | **GET** {rpm_rpm_distribution_href}list_roles/ | List roles
*PulpRpmClient::DistributionsRpmApi* | [**my_permissions**](docs/DistributionsRpmApi.md#my_permissions) | **GET** {rpm_rpm_distribution_href}my_permissions/ | List user permissions
*PulpRpmClient::DistributionsRpmApi* | [**partial_update**](docs/DistributionsRpmApi.md#partial_update) | **PATCH** {rpm_rpm_distribution_href} | Update a rpm distribution
*PulpRpmClient::DistributionsRpmApi* | [**read**](docs/DistributionsRpmApi.md#read) | **GET** {rpm_rpm_distribution_href} | Inspect a rpm distribution
*PulpRpmClient::DistributionsRpmApi* | [**remove_role**](docs/DistributionsRpmApi.md#remove_role) | **POST** {rpm_rpm_distribution_href}remove_role/ | Remove a role
*PulpRpmClient::DistributionsRpmApi* | [**set_label**](docs/DistributionsRpmApi.md#set_label) | **POST** {rpm_rpm_distribution_href}set_label/ | Set a label
*PulpRpmClient::DistributionsRpmApi* | [**unset_label**](docs/DistributionsRpmApi.md#unset_label) | **POST** {rpm_rpm_distribution_href}unset_label/ | Unset a label
*PulpRpmClient::DistributionsRpmApi* | [**update**](docs/DistributionsRpmApi.md#update) | **PUT** {rpm_rpm_distribution_href} | Update a rpm distribution
*PulpRpmClient::PublicationsRpmApi* | [**add_role**](docs/PublicationsRpmApi.md#add_role) | **POST** {rpm_rpm_publication_href}add_role/ | Add a role
*PulpRpmClient::PublicationsRpmApi* | [**create**](docs/PublicationsRpmApi.md#create) | **POST** /pulp/api/v3/publications/rpm/rpm/ | Create a rpm publication
*PulpRpmClient::PublicationsRpmApi* | [**delete**](docs/PublicationsRpmApi.md#delete) | **DELETE** {rpm_rpm_publication_href} | Delete a rpm publication
*PulpRpmClient::PublicationsRpmApi* | [**list**](docs/PublicationsRpmApi.md#list) | **GET** /pulp/api/v3/publications/rpm/rpm/ | List rpm publications
*PulpRpmClient::PublicationsRpmApi* | [**list_roles**](docs/PublicationsRpmApi.md#list_roles) | **GET** {rpm_rpm_publication_href}list_roles/ | List roles
*PulpRpmClient::PublicationsRpmApi* | [**my_permissions**](docs/PublicationsRpmApi.md#my_permissions) | **GET** {rpm_rpm_publication_href}my_permissions/ | List user permissions
*PulpRpmClient::PublicationsRpmApi* | [**read**](docs/PublicationsRpmApi.md#read) | **GET** {rpm_rpm_publication_href} | Inspect a rpm publication
*PulpRpmClient::PublicationsRpmApi* | [**remove_role**](docs/PublicationsRpmApi.md#remove_role) | **POST** {rpm_rpm_publication_href}remove_role/ | Remove a role
*PulpRpmClient::RemotesRpmApi* | [**add_role**](docs/RemotesRpmApi.md#add_role) | **POST** {rpm_rpm_remote_href}add_role/ | Add a role
*PulpRpmClient::RemotesRpmApi* | [**create**](docs/RemotesRpmApi.md#create) | **POST** /pulp/api/v3/remotes/rpm/rpm/ | Create a rpm remote
*PulpRpmClient::RemotesRpmApi* | [**delete**](docs/RemotesRpmApi.md#delete) | **DELETE** {rpm_rpm_remote_href} | Delete a rpm remote
*PulpRpmClient::RemotesRpmApi* | [**list**](docs/RemotesRpmApi.md#list) | **GET** /pulp/api/v3/remotes/rpm/rpm/ | List rpm remotes
*PulpRpmClient::RemotesRpmApi* | [**list_roles**](docs/RemotesRpmApi.md#list_roles) | **GET** {rpm_rpm_remote_href}list_roles/ | List roles
*PulpRpmClient::RemotesRpmApi* | [**my_permissions**](docs/RemotesRpmApi.md#my_permissions) | **GET** {rpm_rpm_remote_href}my_permissions/ | List user permissions
*PulpRpmClient::RemotesRpmApi* | [**partial_update**](docs/RemotesRpmApi.md#partial_update) | **PATCH** {rpm_rpm_remote_href} | Update a rpm remote
*PulpRpmClient::RemotesRpmApi* | [**read**](docs/RemotesRpmApi.md#read) | **GET** {rpm_rpm_remote_href} | Inspect a rpm remote
*PulpRpmClient::RemotesRpmApi* | [**remove_role**](docs/RemotesRpmApi.md#remove_role) | **POST** {rpm_rpm_remote_href}remove_role/ | Remove a role
*PulpRpmClient::RemotesRpmApi* | [**set_label**](docs/RemotesRpmApi.md#set_label) | **POST** {rpm_rpm_remote_href}set_label/ | Set a label
*PulpRpmClient::RemotesRpmApi* | [**unset_label**](docs/RemotesRpmApi.md#unset_label) | **POST** {rpm_rpm_remote_href}unset_label/ | Unset a label
*PulpRpmClient::RemotesRpmApi* | [**update**](docs/RemotesRpmApi.md#update) | **PUT** {rpm_rpm_remote_href} | Update a rpm remote
*PulpRpmClient::RemotesUlnApi* | [**add_role**](docs/RemotesUlnApi.md#add_role) | **POST** {rpm_uln_remote_href}add_role/ | Add a role
*PulpRpmClient::RemotesUlnApi* | [**create**](docs/RemotesUlnApi.md#create) | **POST** /pulp/api/v3/remotes/rpm/uln/ | Create an uln remote
*PulpRpmClient::RemotesUlnApi* | [**delete**](docs/RemotesUlnApi.md#delete) | **DELETE** {rpm_uln_remote_href} | Delete an uln remote
*PulpRpmClient::RemotesUlnApi* | [**list**](docs/RemotesUlnApi.md#list) | **GET** /pulp/api/v3/remotes/rpm/uln/ | List uln remotes
*PulpRpmClient::RemotesUlnApi* | [**list_roles**](docs/RemotesUlnApi.md#list_roles) | **GET** {rpm_uln_remote_href}list_roles/ | List roles
*PulpRpmClient::RemotesUlnApi* | [**my_permissions**](docs/RemotesUlnApi.md#my_permissions) | **GET** {rpm_uln_remote_href}my_permissions/ | List user permissions
*PulpRpmClient::RemotesUlnApi* | [**partial_update**](docs/RemotesUlnApi.md#partial_update) | **PATCH** {rpm_uln_remote_href} | Update an uln remote
*PulpRpmClient::RemotesUlnApi* | [**read**](docs/RemotesUlnApi.md#read) | **GET** {rpm_uln_remote_href} | Inspect an uln remote
*PulpRpmClient::RemotesUlnApi* | [**remove_role**](docs/RemotesUlnApi.md#remove_role) | **POST** {rpm_uln_remote_href}remove_role/ | Remove a role
*PulpRpmClient::RemotesUlnApi* | [**set_label**](docs/RemotesUlnApi.md#set_label) | **POST** {rpm_uln_remote_href}set_label/ | Set a label
*PulpRpmClient::RemotesUlnApi* | [**unset_label**](docs/RemotesUlnApi.md#unset_label) | **POST** {rpm_uln_remote_href}unset_label/ | Unset a label
*PulpRpmClient::RemotesUlnApi* | [**update**](docs/RemotesUlnApi.md#update) | **PUT** {rpm_uln_remote_href} | Update an uln remote
*PulpRpmClient::RepositoriesRpmApi* | [**add_role**](docs/RepositoriesRpmApi.md#add_role) | **POST** {rpm_rpm_repository_href}add_role/ | Add a role
*PulpRpmClient::RepositoriesRpmApi* | [**create**](docs/RepositoriesRpmApi.md#create) | **POST** /pulp/api/v3/repositories/rpm/rpm/ | Create a rpm repository
*PulpRpmClient::RepositoriesRpmApi* | [**delete**](docs/RepositoriesRpmApi.md#delete) | **DELETE** {rpm_rpm_repository_href} | Delete a rpm repository
*PulpRpmClient::RepositoriesRpmApi* | [**list**](docs/RepositoriesRpmApi.md#list) | **GET** /pulp/api/v3/repositories/rpm/rpm/ | List rpm repositorys
*PulpRpmClient::RepositoriesRpmApi* | [**list_roles**](docs/RepositoriesRpmApi.md#list_roles) | **GET** {rpm_rpm_repository_href}list_roles/ | List roles
*PulpRpmClient::RepositoriesRpmApi* | [**modify**](docs/RepositoriesRpmApi.md#modify) | **POST** {rpm_rpm_repository_href}modify/ | Modify Repository Content
*PulpRpmClient::RepositoriesRpmApi* | [**my_permissions**](docs/RepositoriesRpmApi.md#my_permissions) | **GET** {rpm_rpm_repository_href}my_permissions/ | List user permissions
*PulpRpmClient::RepositoriesRpmApi* | [**partial_update**](docs/RepositoriesRpmApi.md#partial_update) | **PATCH** {rpm_rpm_repository_href} | Update a rpm repository
*PulpRpmClient::RepositoriesRpmApi* | [**read**](docs/RepositoriesRpmApi.md#read) | **GET** {rpm_rpm_repository_href} | Inspect a rpm repository
*PulpRpmClient::RepositoriesRpmApi* | [**remove_role**](docs/RepositoriesRpmApi.md#remove_role) | **POST** {rpm_rpm_repository_href}remove_role/ | Remove a role
*PulpRpmClient::RepositoriesRpmApi* | [**set_label**](docs/RepositoriesRpmApi.md#set_label) | **POST** {rpm_rpm_repository_href}set_label/ | Set a label
*PulpRpmClient::RepositoriesRpmApi* | [**sync**](docs/RepositoriesRpmApi.md#sync) | **POST** {rpm_rpm_repository_href}sync/ | Sync from remote
*PulpRpmClient::RepositoriesRpmApi* | [**unset_label**](docs/RepositoriesRpmApi.md#unset_label) | **POST** {rpm_rpm_repository_href}unset_label/ | Unset a label
*PulpRpmClient::RepositoriesRpmApi* | [**update**](docs/RepositoriesRpmApi.md#update) | **PUT** {rpm_rpm_repository_href} | Update a rpm repository
*PulpRpmClient::RepositoriesRpmVersionsApi* | [**delete**](docs/RepositoriesRpmVersionsApi.md#delete) | **DELETE** {rpm_rpm_repository_version_href} | Delete a repository version
*PulpRpmClient::RepositoriesRpmVersionsApi* | [**list**](docs/RepositoriesRpmVersionsApi.md#list) | **GET** {rpm_rpm_repository_href}versions/ | List repository versions
*PulpRpmClient::RepositoriesRpmVersionsApi* | [**read**](docs/RepositoriesRpmVersionsApi.md#read) | **GET** {rpm_rpm_repository_version_href} | Inspect a repository version
*PulpRpmClient::RepositoriesRpmVersionsApi* | [**repair**](docs/RepositoriesRpmVersionsApi.md#repair) | **POST** {rpm_rpm_repository_version_href}repair/ | 
*PulpRpmClient::RpmCompsApi* | [**rpm_comps_upload**](docs/RpmCompsApi.md#rpm_comps_upload) | **POST** /pulp/api/v3/rpm/comps/ | Upload comps.xml
*PulpRpmClient::RpmCopyApi* | [**copy_content**](docs/RpmCopyApi.md#copy_content) | **POST** /pulp/api/v3/rpm/copy/ | Copy content


## Documentation for Models

 - [PulpRpmClient::AddonResponse](docs/AddonResponse.md)
 - [PulpRpmClient::ArtifactResponse](docs/ArtifactResponse.md)
 - [PulpRpmClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpRpmClient::ChecksumResponse](docs/ChecksumResponse.md)
 - [PulpRpmClient::CompressionTypeEnum](docs/CompressionTypeEnum.md)
 - [PulpRpmClient::CompsXml](docs/CompsXml.md)
 - [PulpRpmClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpRpmClient::Copy](docs/Copy.md)
 - [PulpRpmClient::ImageResponse](docs/ImageResponse.md)
 - [PulpRpmClient::MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [PulpRpmClient::NestedRole](docs/NestedRole.md)
 - [PulpRpmClient::NestedRoleResponse](docs/NestedRoleResponse.md)
 - [PulpRpmClient::ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [PulpRpmClient::PackageChecksumTypeEnum](docs/PackageChecksumTypeEnum.md)
 - [PulpRpmClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpRpmClient::PaginatedrpmDistributionTreeResponseList](docs/PaginatedrpmDistributionTreeResponseList.md)
 - [PulpRpmClient::PaginatedrpmModulemdDefaultsResponseList](docs/PaginatedrpmModulemdDefaultsResponseList.md)
 - [PulpRpmClient::PaginatedrpmModulemdObsoleteResponseList](docs/PaginatedrpmModulemdObsoleteResponseList.md)
 - [PulpRpmClient::PaginatedrpmModulemdResponseList](docs/PaginatedrpmModulemdResponseList.md)
 - [PulpRpmClient::PaginatedrpmPackageCategoryResponseList](docs/PaginatedrpmPackageCategoryResponseList.md)
 - [PulpRpmClient::PaginatedrpmPackageEnvironmentResponseList](docs/PaginatedrpmPackageEnvironmentResponseList.md)
 - [PulpRpmClient::PaginatedrpmPackageGroupResponseList](docs/PaginatedrpmPackageGroupResponseList.md)
 - [PulpRpmClient::PaginatedrpmPackageLangpacksResponseList](docs/PaginatedrpmPackageLangpacksResponseList.md)
 - [PulpRpmClient::PaginatedrpmPackageResponseList](docs/PaginatedrpmPackageResponseList.md)
 - [PulpRpmClient::PaginatedrpmRepoMetadataFileResponseList](docs/PaginatedrpmRepoMetadataFileResponseList.md)
 - [PulpRpmClient::PaginatedrpmRpmAlternateContentSourceResponseList](docs/PaginatedrpmRpmAlternateContentSourceResponseList.md)
 - [PulpRpmClient::PaginatedrpmRpmDistributionResponseList](docs/PaginatedrpmRpmDistributionResponseList.md)
 - [PulpRpmClient::PaginatedrpmRpmPublicationResponseList](docs/PaginatedrpmRpmPublicationResponseList.md)
 - [PulpRpmClient::PaginatedrpmRpmRemoteResponseList](docs/PaginatedrpmRpmRemoteResponseList.md)
 - [PulpRpmClient::PaginatedrpmRpmRepositoryResponseList](docs/PaginatedrpmRpmRepositoryResponseList.md)
 - [PulpRpmClient::PaginatedrpmUlnRemoteResponseList](docs/PaginatedrpmUlnRemoteResponseList.md)
 - [PulpRpmClient::PaginatedrpmUpdateRecordResponseList](docs/PaginatedrpmUpdateRecordResponseList.md)
 - [PulpRpmClient::PatchedrpmRpmAlternateContentSource](docs/PatchedrpmRpmAlternateContentSource.md)
 - [PulpRpmClient::PatchedrpmRpmDistribution](docs/PatchedrpmRpmDistribution.md)
 - [PulpRpmClient::PatchedrpmRpmRemote](docs/PatchedrpmRpmRemote.md)
 - [PulpRpmClient::PatchedrpmRpmRepository](docs/PatchedrpmRpmRepository.md)
 - [PulpRpmClient::PatchedrpmUlnRemote](docs/PatchedrpmUlnRemote.md)
 - [PulpRpmClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpRpmClient::Repair](docs/Repair.md)
 - [PulpRpmClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpRpmClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpRpmClient::RpmDistributionTreeResponse](docs/RpmDistributionTreeResponse.md)
 - [PulpRpmClient::RpmModulemd](docs/RpmModulemd.md)
 - [PulpRpmClient::RpmModulemdDefaults](docs/RpmModulemdDefaults.md)
 - [PulpRpmClient::RpmModulemdDefaultsResponse](docs/RpmModulemdDefaultsResponse.md)
 - [PulpRpmClient::RpmModulemdObsolete](docs/RpmModulemdObsolete.md)
 - [PulpRpmClient::RpmModulemdObsoleteResponse](docs/RpmModulemdObsoleteResponse.md)
 - [PulpRpmClient::RpmModulemdResponse](docs/RpmModulemdResponse.md)
 - [PulpRpmClient::RpmPackage](docs/RpmPackage.md)
 - [PulpRpmClient::RpmPackageCategoryResponse](docs/RpmPackageCategoryResponse.md)
 - [PulpRpmClient::RpmPackageEnvironmentResponse](docs/RpmPackageEnvironmentResponse.md)
 - [PulpRpmClient::RpmPackageGroupResponse](docs/RpmPackageGroupResponse.md)
 - [PulpRpmClient::RpmPackageLangpacksResponse](docs/RpmPackageLangpacksResponse.md)
 - [PulpRpmClient::RpmPackageResponse](docs/RpmPackageResponse.md)
 - [PulpRpmClient::RpmRepoMetadataFileResponse](docs/RpmRepoMetadataFileResponse.md)
 - [PulpRpmClient::RpmRepositorySyncURL](docs/RpmRepositorySyncURL.md)
 - [PulpRpmClient::RpmRpmAlternateContentSource](docs/RpmRpmAlternateContentSource.md)
 - [PulpRpmClient::RpmRpmAlternateContentSourceResponse](docs/RpmRpmAlternateContentSourceResponse.md)
 - [PulpRpmClient::RpmRpmDistribution](docs/RpmRpmDistribution.md)
 - [PulpRpmClient::RpmRpmDistributionResponse](docs/RpmRpmDistributionResponse.md)
 - [PulpRpmClient::RpmRpmPublication](docs/RpmRpmPublication.md)
 - [PulpRpmClient::RpmRpmPublicationResponse](docs/RpmRpmPublicationResponse.md)
 - [PulpRpmClient::RpmRpmRemote](docs/RpmRpmRemote.md)
 - [PulpRpmClient::RpmRpmRemoteResponse](docs/RpmRpmRemoteResponse.md)
 - [PulpRpmClient::RpmRpmRemoteResponseHiddenFields](docs/RpmRpmRemoteResponseHiddenFields.md)
 - [PulpRpmClient::RpmRpmRepository](docs/RpmRpmRepository.md)
 - [PulpRpmClient::RpmRpmRepositoryResponse](docs/RpmRpmRepositoryResponse.md)
 - [PulpRpmClient::RpmUlnRemote](docs/RpmUlnRemote.md)
 - [PulpRpmClient::RpmUlnRemoteResponse](docs/RpmUlnRemoteResponse.md)
 - [PulpRpmClient::RpmUpdateCollection](docs/RpmUpdateCollection.md)
 - [PulpRpmClient::RpmUpdateCollectionResponse](docs/RpmUpdateCollectionResponse.md)
 - [PulpRpmClient::RpmUpdateRecord](docs/RpmUpdateRecord.md)
 - [PulpRpmClient::RpmUpdateRecordResponse](docs/RpmUpdateRecordResponse.md)
 - [PulpRpmClient::SetLabel](docs/SetLabel.md)
 - [PulpRpmClient::SetLabelResponse](docs/SetLabelResponse.md)
 - [PulpRpmClient::SkipTypesEnum](docs/SkipTypesEnum.md)
 - [PulpRpmClient::SyncPolicyEnum](docs/SyncPolicyEnum.md)
 - [PulpRpmClient::TaskGroupOperationResponse](docs/TaskGroupOperationResponse.md)
 - [PulpRpmClient::UnsetLabel](docs/UnsetLabel.md)
 - [PulpRpmClient::UnsetLabelResponse](docs/UnsetLabelResponse.md)
 - [PulpRpmClient::VariantResponse](docs/VariantResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

