# PulpRpmClient::ContentPackagesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/rpm/packages/ | Create a package
[**list**](ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/rpm/packages/ | List packages
[**read**](ContentPackagesApi.md#read) | **GET** {rpm_package_href} | Inspect a package



## create

> AsyncOperationResponse create(opts)

Create a package

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentPackagesApi.new
opts = {
  repository: 'repository_example', # String | A URI of a repository the new content unit should be associated with.
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  relative_path: 'relative_path_example', # String | Path where the artifact is located relative to distributions base_path
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the content unit.
  upload: 'upload_example' # String | An uncommitted upload that may be turned into the content unit.
}

begin
  #Create a package
  result = api_instance.create(opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 
 **artifact** | **String**| Artifact file representing the physical content | [optional] 
 **relative_path** | **String**| Path where the artifact is located relative to distributions base_path | [optional] 
 **file** | **File**| An uploaded file that may be turned into the content unit. | [optional] 
 **upload** | **String**| An uncommitted upload that may be turned into the content unit. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginatedrpmPackageResponseList list(opts)

List packages

A ViewSet for Package.  Define endpoint name which will appear in the API endpoint for this content type. For example::     http://pulp.example.com/pulp/api/v3/content/rpm/packages/  Also specify queryset and serializer for Package.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentPackagesApi.new
opts = {
  arch: 'arch_example', # String | Filter results where arch matches value
  arch__contains: 'arch__contains_example', # String | Filter results where arch contains value
  arch__in: ['arch__in_example'], # Array<String> | Filter results where arch is in a comma-separated list of values
  arch__ne: 'arch__ne_example', # String | Filter results where arch not equal to value
  arch__startswith: 'arch__startswith_example', # String | Filter results where arch starts with value
  checksum_type: 'checksum_type_example', # String | Filter results where checksum_type matches value  * `unknown` - unknown * `md5` - md5 * `sha1` - sha1 * `sha1` - sha1 * `sha224` - sha224 * `sha256` - sha256 * `sha384` - sha384 * `sha512` - sha512
  checksum_type__in: ['checksum_type__in_example'], # Array<String> | Filter results where checksum_type is in a comma-separated list of values
  checksum_type__ne: 'checksum_type__ne_example', # String | Filter results where checksum_type not equal to value
  epoch: 'epoch_example', # String | Filter results where epoch matches value
  epoch__in: ['epoch__in_example'], # Array<String> | Filter results where epoch is in a comma-separated list of values
  epoch__ne: 'epoch__ne_example', # String | Filter results where epoch not equal to value
  filename: 'filename_example', # String | 
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__ne: 'name__ne_example', # String | Filter results where name not equal to value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `name` - Name * `-name` - Name (descending) * `epoch` - Epoch * `-epoch` - Epoch (descending) * `version` - Version * `-version` - Version (descending) * `release` - Release * `-release` - Release (descending) * `arch` - Arch * `-arch` - Arch (descending) * `evr` - Evr * `-evr` - Evr (descending) * `pkgId` - Pkgid * `-pkgId` - Pkgid (descending) * `checksum_type` - Checksum type * `-checksum_type` - Checksum type (descending) * `summary` - Summary * `-summary` - Summary (descending) * `description` - Description * `-description` - Description (descending) * `url` - Url * `-url` - Url (descending) * `changelogs` - Changelogs * `-changelogs` - Changelogs (descending) * `files` - Files * `-files` - Files (descending) * `requires` - Requires * `-requires` - Requires (descending) * `provides` - Provides * `-provides` - Provides (descending) * `conflicts` - Conflicts * `-conflicts` - Conflicts (descending) * `obsoletes` - Obsoletes * `-obsoletes` - Obsoletes (descending) * `suggests` - Suggests * `-suggests` - Suggests (descending) * `enhances` - Enhances * `-enhances` - Enhances (descending) * `recommends` - Recommends * `-recommends` - Recommends (descending) * `supplements` - Supplements * `-supplements` - Supplements (descending) * `location_base` - Location base * `-location_base` - Location base (descending) * `location_href` - Location href * `-location_href` - Location href (descending) * `rpm_buildhost` - Rpm buildhost * `-rpm_buildhost` - Rpm buildhost (descending) * `rpm_group` - Rpm group * `-rpm_group` - Rpm group (descending) * `rpm_license` - Rpm license * `-rpm_license` - Rpm license (descending) * `rpm_packager` - Rpm packager * `-rpm_packager` - Rpm packager (descending) * `rpm_sourcerpm` - Rpm sourcerpm * `-rpm_sourcerpm` - Rpm sourcerpm (descending) * `rpm_vendor` - Rpm vendor * `-rpm_vendor` - Rpm vendor (descending) * `rpm_header_start` - Rpm header start * `-rpm_header_start` - Rpm header start (descending) * `rpm_header_end` - Rpm header end * `-rpm_header_end` - Rpm header end (descending) * `size_archive` - Size archive * `-size_archive` - Size archive (descending) * `size_installed` - Size installed * `-size_installed` - Size installed (descending) * `size_package` - Size package * `-size_package` - Size package (descending) * `time_build` - Time build * `-time_build` - Time build (descending) * `time_file` - Time file * `-time_file` - Time file (descending) * `is_modular` - Is modular * `-is_modular` - Is modular (descending) * `pk` - Pk * `-pk` - Pk (descending)
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  pkg_id: 'pkg_id_example', # String | Filter results where pkgId matches value
  pkg_id__in: ['pkg_id__in_example'], # Array<String> | Filter results where pkgId is in a comma-separated list of values
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  release: 'release_example', # String | Filter results where release matches value
  release__contains: 'release__contains_example', # String | Filter results where release contains value
  release__in: ['release__in_example'], # Array<String> | Filter results where release is in a comma-separated list of values
  release__ne: 'release__ne_example', # String | Filter results where release not equal to value
  release__startswith: 'release__startswith_example', # String | Filter results where release starts with value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  sha256: 'sha256_example', # String | 
  version: 'version_example', # String | Filter results where version matches value
  version__in: ['version__in_example'], # Array<String> | Filter results where version is in a comma-separated list of values
  version__ne: 'version__ne_example', # String | Filter results where version not equal to value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List packages
  result = api_instance.list(opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **arch** | **String**| Filter results where arch matches value | [optional] 
 **arch__contains** | **String**| Filter results where arch contains value | [optional] 
 **arch__in** | [**Array&lt;String&gt;**](String.md)| Filter results where arch is in a comma-separated list of values | [optional] 
 **arch__ne** | **String**| Filter results where arch not equal to value | [optional] 
 **arch__startswith** | **String**| Filter results where arch starts with value | [optional] 
 **checksum_type** | **String**| Filter results where checksum_type matches value  * &#x60;unknown&#x60; - unknown * &#x60;md5&#x60; - md5 * &#x60;sha1&#x60; - sha1 * &#x60;sha1&#x60; - sha1 * &#x60;sha224&#x60; - sha224 * &#x60;sha256&#x60; - sha256 * &#x60;sha384&#x60; - sha384 * &#x60;sha512&#x60; - sha512 | [optional] 
 **checksum_type__in** | [**Array&lt;String&gt;**](String.md)| Filter results where checksum_type is in a comma-separated list of values | [optional] 
 **checksum_type__ne** | **String**| Filter results where checksum_type not equal to value | [optional] 
 **epoch** | **String**| Filter results where epoch matches value | [optional] 
 **epoch__in** | [**Array&lt;String&gt;**](String.md)| Filter results where epoch is in a comma-separated list of values | [optional] 
 **epoch__ne** | **String**| Filter results where epoch not equal to value | [optional] 
 **filename** | **String**|  | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__ne** | **String**| Filter results where name not equal to value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;epoch&#x60; - Epoch * &#x60;-epoch&#x60; - Epoch (descending) * &#x60;version&#x60; - Version * &#x60;-version&#x60; - Version (descending) * &#x60;release&#x60; - Release * &#x60;-release&#x60; - Release (descending) * &#x60;arch&#x60; - Arch * &#x60;-arch&#x60; - Arch (descending) * &#x60;evr&#x60; - Evr * &#x60;-evr&#x60; - Evr (descending) * &#x60;pkgId&#x60; - Pkgid * &#x60;-pkgId&#x60; - Pkgid (descending) * &#x60;checksum_type&#x60; - Checksum type * &#x60;-checksum_type&#x60; - Checksum type (descending) * &#x60;summary&#x60; - Summary * &#x60;-summary&#x60; - Summary (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;url&#x60; - Url * &#x60;-url&#x60; - Url (descending) * &#x60;changelogs&#x60; - Changelogs * &#x60;-changelogs&#x60; - Changelogs (descending) * &#x60;files&#x60; - Files * &#x60;-files&#x60; - Files (descending) * &#x60;requires&#x60; - Requires * &#x60;-requires&#x60; - Requires (descending) * &#x60;provides&#x60; - Provides * &#x60;-provides&#x60; - Provides (descending) * &#x60;conflicts&#x60; - Conflicts * &#x60;-conflicts&#x60; - Conflicts (descending) * &#x60;obsoletes&#x60; - Obsoletes * &#x60;-obsoletes&#x60; - Obsoletes (descending) * &#x60;suggests&#x60; - Suggests * &#x60;-suggests&#x60; - Suggests (descending) * &#x60;enhances&#x60; - Enhances * &#x60;-enhances&#x60; - Enhances (descending) * &#x60;recommends&#x60; - Recommends * &#x60;-recommends&#x60; - Recommends (descending) * &#x60;supplements&#x60; - Supplements * &#x60;-supplements&#x60; - Supplements (descending) * &#x60;location_base&#x60; - Location base * &#x60;-location_base&#x60; - Location base (descending) * &#x60;location_href&#x60; - Location href * &#x60;-location_href&#x60; - Location href (descending) * &#x60;rpm_buildhost&#x60; - Rpm buildhost * &#x60;-rpm_buildhost&#x60; - Rpm buildhost (descending) * &#x60;rpm_group&#x60; - Rpm group * &#x60;-rpm_group&#x60; - Rpm group (descending) * &#x60;rpm_license&#x60; - Rpm license * &#x60;-rpm_license&#x60; - Rpm license (descending) * &#x60;rpm_packager&#x60; - Rpm packager * &#x60;-rpm_packager&#x60; - Rpm packager (descending) * &#x60;rpm_sourcerpm&#x60; - Rpm sourcerpm * &#x60;-rpm_sourcerpm&#x60; - Rpm sourcerpm (descending) * &#x60;rpm_vendor&#x60; - Rpm vendor * &#x60;-rpm_vendor&#x60; - Rpm vendor (descending) * &#x60;rpm_header_start&#x60; - Rpm header start * &#x60;-rpm_header_start&#x60; - Rpm header start (descending) * &#x60;rpm_header_end&#x60; - Rpm header end * &#x60;-rpm_header_end&#x60; - Rpm header end (descending) * &#x60;size_archive&#x60; - Size archive * &#x60;-size_archive&#x60; - Size archive (descending) * &#x60;size_installed&#x60; - Size installed * &#x60;-size_installed&#x60; - Size installed (descending) * &#x60;size_package&#x60; - Size package * &#x60;-size_package&#x60; - Size package (descending) * &#x60;time_build&#x60; - Time build * &#x60;-time_build&#x60; - Time build (descending) * &#x60;time_file&#x60; - Time file * &#x60;-time_file&#x60; - Time file (descending) * &#x60;is_modular&#x60; - Is modular * &#x60;-is_modular&#x60; - Is modular (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **pkg_id** | **String**| Filter results where pkgId matches value | [optional] 
 **pkg_id__in** | [**Array&lt;String&gt;**](String.md)| Filter results where pkgId is in a comma-separated list of values | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **release** | **String**| Filter results where release matches value | [optional] 
 **release__contains** | **String**| Filter results where release contains value | [optional] 
 **release__in** | [**Array&lt;String&gt;**](String.md)| Filter results where release is in a comma-separated list of values | [optional] 
 **release__ne** | **String**| Filter results where release not equal to value | [optional] 
 **release__startswith** | **String**| Filter results where release starts with value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **sha256** | **String**|  | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **version__in** | [**Array&lt;String&gt;**](String.md)| Filter results where version is in a comma-separated list of values | [optional] 
 **version__ne** | **String**| Filter results where version not equal to value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedrpmPackageResponseList**](PaginatedrpmPackageResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> RpmPackageResponse read(rpm_package_href, opts)

Inspect a package

A ViewSet for Package.  Define endpoint name which will appear in the API endpoint for this content type. For example::     http://pulp.example.com/pulp/api/v3/content/rpm/packages/  Also specify queryset and serializer for Package.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentPackagesApi.new
rpm_package_href = 'rpm_package_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a package
  result = api_instance.read(rpm_package_href, opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rpm_package_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**RpmPackageResponse**](RpmPackageResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

